{% extends "base.html" %}

{% block content %}
<div class="text-center">
    <h1 class="display-4 mb-4">Welcome to LlamaBot</h1>
    <p class="lead">Redirecting to logs...</p>
</div>

<script>
    window.location.href = '/logs';
</script>
{% endblock %}
